Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-05-05 18:03:12 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-05-05 18:03:12 +0400
commita731e130432a98ab8228112027cd3eaa8ed700b1 (patch)
treee71dad8f907ccd4a73b7bbc1ad166eda2dfba9cf /source/blender/editors/render/render_preview.c
parenta30dec8e5968ae6568184cfdc2e1a69bad0e39d6 (diff)
code cleanup: function naming, use BKE_*type* prefix.
Diffstat (limited to 'source/blender/editors/render/render_preview.c')
-rw-r--r--source/blender/editors/render/render_preview.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/editors/render/render_preview.c b/source/blender/editors/render/render_preview.c
index 32ed74097e1..f7024444e86 100644
--- a/source/blender/editors/render/render_preview.c
+++ b/source/blender/editors/render/render_preview.c
@@ -754,13 +754,13 @@ static void shader_preview_free(void *customdata)
/* get rid of copied material */
BLI_remlink(&pr_main->mat, sp->matcopy);
/* free_material decrements texture, prevent this. hack alert! */
for (a = 0; a < MAX_MTEX; a++) {
MTex *mtex = sp->matcopy->mtex[a];
if (mtex && mtex->tex) mtex->tex = NULL;
}
- free_material(sp->matcopy);
+ BKE_material_free(sp->matcopy);
properties = IDP_GetProperties((ID *)sp->matcopy, FALSE);
if (properties) {
@@ -776,7 +776,7 @@ static void shader_preview_free(void *customdata)
/* get rid of copied texture */
BLI_remlink(&pr_main->tex, sp->texcopy);
- free_texture(sp->texcopy);
+ BKE_texture_free(sp->texcopy);
properties = IDP_GetProperties((ID *)sp->texcopy, FALSE);
if (properties) {
@@ -792,7 +792,7 @@ static void shader_preview_free(void *customdata)
/* get rid of copied world */
BLI_remlink(&pr_main->world, sp->worldcopy);
- free_world(sp->worldcopy);
+ BKE_world_free(sp->worldcopy);
properties = IDP_GetProperties((ID *)sp->worldcopy, FALSE);
if (properties) {
@@ -808,7 +808,7 @@ static void shader_preview_free(void *customdata)
/* get rid of copied lamp */
BLI_remlink(&pr_main->lamp, sp->lampcopy);
- free_lamp(sp->lampcopy);
+ BKE_lamp_free(sp->lampcopy);
properties = IDP_GetProperties((ID *)sp->lampcopy, FALSE);
if (properties) {
@@ -754,13 +754,13 @@ static void shader_preview_free(void *customdata)
/* get rid of copied material */
BLI_remlink(&pr_main->mat, sp->matcopy);
- /* free_material decrements texture, prevent this. hack alert! */
+ /* BKE_material_free decrements texture, prevent this. hack alert! */
for (a = 0; a < MAX_MTEX; a++) {
MTex *mtex = sp->matcopy->mtex[a];